"use strict";
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
Object.defineProperty(exports, "__esModule", { value: true });
var index_1 = require("../index");
var path = require("path");
var fs = require("fs");
var root = path.resolve(__dirname, './test-project');
var baseUrl = '.';
var alias1 = {
    '@': 'src',
    '@components': './src/components',
    '@hooks': './src/hooks',
    '@utils': './src/utils',
};
var alias2 = {
    '#': 'src',
    '#components': './src/components',
    '#hooks': './src/hooks',
    '#utils': './src/utils',
};
var expectedFile1 = {
    compilerOptions: {
        baseUrl: baseUrl,
        paths: {
            '@/*': ['src/*'],
            '@components/*': ['./src/components/*'],
            '@hooks/*': ['./src/hooks/*'],
            '@utils/*': ['./src/utils/*'],
        },
    },
};
var expectedFile2 = {
    compilerOptions: {
        baseUrl: baseUrl,
        paths: {
            '#/*': ['src/*'],
            '#components/*': ['./src/components/*'],
            '#hooks/*': ['./src/hooks/*'],
            '#utils/*': ['./src/utils/*'],
        },
    },
};
var tests = [
    {
        root: root,
        baseUrl: baseUrl,
    },
    {
        root: root,
        baseUrl: baseUrl,
        jsconfig: "./jsconfig1.json",
        tsconfig: "./tsconfig1.json",
    },
    {
        root: root,
        baseUrl: baseUrl,
        jsconfig: ["./jsconfig2.json", "./jsconfig3.json"],
        tsconfig: ["./tsconfig2.json", "./tsconfig3.json"],
    },
];
var cycle = 0;
var runTest = function (options, index, alias, expectedFile, shouldDeleteFile) {
    if (options === void 0) { options = tests[0]; }
    if (index === void 0) { index = 0; }
    if (alias === void 0) { alias = alias1; }
    if (shouldDeleteFile === void 0) { shouldDeleteFile = false; }
    var prefix = "Alias ".concat(cycle++);
    var hasFiles = index > 0;
    var hasArrayFiles = index === 2;
    var files = [];
    if (hasFiles) {
        if (hasArrayFiles) {
            files = __spreadArray(__spreadArray([], options.jsconfig, true), options.tsconfig, true);
        }
        else {
            files = [options.jsconfig, options.tsconfig];
        }
    }
    // test createAlias alias1
    var created = (0, index_1.createAlias)(alias, options);
    test("".concat(prefix, " - created alias"), function () {
        expect(created).toEqual(alias);
    });
    if (hasFiles) {
        files.forEach(function (file) {
            var filePath = path.resolve(options.root, file);
            var json = fs.readFileSync(filePath, 'utf8');
            var data = JSON.parse(json);
            test("".concat(prefix, " - ").concat(file, " - file data"), function () {
                expect(data).toEqual(expectedFile);
            });
            if (shouldDeleteFile) {
                fs.unlinkSync(filePath);
            }
        });
    }
};
tests.forEach(function (options, index) {
    runTest(options, index, alias1, expectedFile1, true);
});
tests.forEach(function (options, index) {
    runTest(options, index, alias2, expectedFile2, true);
});
